CALENDARS = {'Public':'successionecological.com_1hm3pcniuvqhdmb7o6ck2h6los@group.calendar.google.com',
			 'Sunrise and sunset for Portland': 'i_71.63.230.104#sunrise@group.v.calendar.google.com',
			 'Billing': 'successionecological.com_pblbamsiu4k5mat5rugaoa8rj0@group.calendar.google.com',
			 'Track': 'successionecological.com_hel9t9nqhjeps9n7db9p15l6us@group.calendar.google.com',
			 'Plan': 'successionecological.com_drr6pddm7b5cn4efu2stp8qsc8@group.calendar.google.com'}
